@@ -11,7 +11,6 @@ from cameo_claw.cameo_claw import it_chunk
 
 from pydantic import BaseModel
 import polars as pl
-import asyncio
 
 app = FastAPI()
 app.add_middleware(CORSMiddleware,
@@ -43,8 +42,6 @@ async def it_streaming(i: ItemUrlFilter):
                 yield bytes1
             else:
                 continue
-    except asyncio.CancelledError:
-        print("caught cancelled error")
     except Exception as e:
         print('it_streaming,exception:', e)
 
@@ -75,5 +72,5 @@ async def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20426):
+def server(host='0.0.0.0', int_port=20427):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
